@@ -75,7 +75,9 @@ model DAYHOFF=
 0 201 23 0 0 0 0 0 27 0 46 0 0 76 0 75 0
 24 8 95 0 96 0 22 0 127 37 28 13 0 698 0 34 42 61
 208 24 15 18 49 35 37 54 44 889 175 10 258 12 48 30 157 0 28
-0.087127 0.040904 0.040432 0.046872 0.033474 0.038255 0.049530 0.088612 0.033618 0.036886 0.085357 0.080482 0.014753 0.039772 0.050680 0.069577 0.058542 0.010494 0.029916 0.064717;
+0.08712691 0.04090396 0.04043196 0.04687195 0.03347397 0.03825496 0.04952995 0.08861191 0.03361897 0.03688596 0.08535691 0.08048092 0.01475299 0.03977196 0.05067995 0.06957693 0.05854194 0.01049399 0.02991597 0.06471794;
+[ NOTE 2019-06-04: normalised from original Dayhoff freqs, which do not sum to 1.0
+ https://www.ebi.ac.uk/goldman-srv/dayhoff/dayhoff-dcmut.dat ]
 
 model DCMUT=
 26.7828
@@ -97,7 +99,9 @@ model DCMUT=
 0.0000 200.1375 22.4968 0.0000 0.0000 0.0000 0.0000 0.0000 27.0564 0.0000 46.1776 0.0000 0.0000 76.2354 0.0000 74.0819 0.0000
 24.4139 7.8012 94.6940 0.0000 95.3164 0.0000 21.4717 0.0000 126.5400 37.4834 28.6572 13.2142 0.0000 695.2629 0.0000 33.6289 41.7839 60.8070
 205.9564 24.0368 15.8067 17.8316 48.4678 34.6983 36.7250 53.8165 43.8715 881.0038 174.5156 10.3850 256.5955 12.3606 48.5026 30.3836 156.1997 0.0000 27.9379
-0.087127 0.040904 0.040432 0.046872 0.033474 0.038255 0.049530 0.088612 0.033619 0.036886 0.085357 0.080481 0.014753 0.039772 0.050680 0.069577 0.058542 0.010494 0.029916 0.064717;
+ 0.08712691 0.04090396 0.04043196 0.04687195 0.03347397 0.03825496 0.04952995 0.08861191 0.03361897 0.03688596 0.08535691 0.08048092 0.01475299 0.03977196 0.05067995 0.06957693 0.05854194 0.01049399 0.02991597 0.06471794;
+[ NOTE 2019-06-04: normalised from original Dayhoff-DCMUT freqs, which do not sum to 1.0
+  https://www.ebi.ac.uk/goldman-srv/dayhoff/dayhoff-dcmut.dat ]
 
 model JTT=
 58
@@ -119,7 +123,8 @@ model JTT=
 9 126 8 4 115 18 10 55 8 9 52 10 24 53 6 35 12
 11 20 70 46 209 24 7 8 573 32 24 8 18 536 10 63 21 71
 298 17 16 31 62 20 45 47 11 961 180 14 323 62 23 38 112 25 16
-0.076748 0.051691 0.042645 0.051544 0.019803 0.040752 0.061830 0.073152 0.022944 0.053761 0.091904 0.058676 0.023826 0.040126 0.050901 0.068765 0.058565 0.014261 0.032102 0.066004;
+0.07674792 0.05169095 0.04264496 0.05154395 0.01980298 0.04075196 0.06182994 0.07315193 0.02294398 0.05376095 0.09190391 0.05867594 0.02382598 0.04012596 0.05090095 0.06876493 0.05856494 0.01426099 0.03210197 0.06600493;
+[ NOTE 2019-06-04: original JTT freqs do not sum to 1.0, taken from PAML package ]
 
 model MTREV=
 23.18
@@ -142,7 +147,9 @@ model MTREV=
 6.48 1.90 191.36 21.21 254.77 38.82 13.12 3.21 670.14 25.01 44.15 51.17 39.96 465.58 16.21 64.92 38.73 26.25
 195.06 7.64 1.90 1.90 1.90 19.00 21.14 2.53 1.90 1222.94 91.67 1.90 387.54 6.35 8.23 1.90 204.54 5.37 1.90
 0.072 0.019 0.039 0.019 0.006 0.025 0.024 0.056 0.028 0.088 0.169 0.023 0.054 0.061 0.054 0.072 0.086 0.029 0.033 0.043;
-
+[ NOTE 2019-06-04: The PI's used to sum to 0.999 and I (Z. Yang) changed one of the freq from 0.168
+  into 0.169 so that the sum is 1.  Prepared by Z. Yang ]
+ 
 model WAG=
 55.15710
 50.98480 63.53460
@@ -163,8 +170,8 @@ model WAG=
 11.31330 116.39200 7.19167 12.97670 71.70700 21.57370 15.65570 33.69830 26.25690 21.24830 66.53090 13.75050 51.57060 152.96400 13.94050 52.37420 11.08640
 24.07350 38.15330 108.60000 32.57110 54.38330 22.77100 19.63030 10.36040 387.34400 42.01700 39.86180 13.32640 42.84370 645.42800 21.60460 78.69930 29.11480 248.53900
 200.60100 25.18490 19.62460 15.23350 100.21400 30.12810 58.87310 18.72470 11.83580 782.13000 180.03400 30.54340 205.84500 64.98920 31.48870 23.27390 138.82300 36.53690 31.47300
-
-0.0866279 0.043972 0.0390894 0.0570451 0.0193078 0.0367281 0.0580589 0.0832518 0.0244313 0.048466 0.086209 0.0620286 0.0195027 0.0384319 0.0457631 0.0695179 0.0610127 0.0143859 0.0352742 0.0708957;
+0.08662791 0.043972 0.0390894 0.05704511 0.0193078 0.0367281 0.05805891 0.08325181 0.0244313 0.048466 0.08620901 0.06202861 0.0195027 0.0384319 0.0457631 0.06951791 0.06101271 0.0143859 0.0352742 0.07089561;
+[ NOTE 2019-06-04: normalised from original WAG freqs, which do not sum to 1.0 ]
 
 model RTREV=
 34
@@ -208,7 +215,8 @@ model CPREV=
 14 230 40 18 435 53 63 82 69 42 159 10 86 468 49 73 29
 56 323 754 281 1466 391 142 10 1971 89 189 247 215 2370 97 522 71 346
 968 92 83 75 592 54 200 91 25 4797 865 249 475 317 122 167 760 10 119
-0.0760 0.0620 0.0410 0.0370 0.0090 0.0380 0.0490 0.0840 0.0250 0.0810 0.1010 0.0500 0.0220 0.0510 0.0430 0.0620 0.0540 0.0180 0.0310 0.0660;
+0.0755 0.0621 0.0410 0.0371 0.0091 0.0382 0.0495 0.0838 0.0246 0.0806 0.1011 0.0504 0.0220 0.0506 0.0431 0.0622 0.0543 0.0181 0.0307 0.0660;
+[ NOTE 2019-06-04: CPREV freqs taken from PAML package with higher precision ]
 
 model VT=
 1.2412691067876198
@@ -296,7 +304,9 @@ model LG=
 0.180717 0.593607 0.045376 0.029890 0.670128 0.236199 0.077852 0.268491 0.597054 0.111660 0.619632 0.049906 0.696175 2.457121 0.095131 0.248862 0.140825
 0.218959 0.314440 0.612025 0.135107 1.165532 0.257336 0.120037 0.054679 5.306834 0.232523 0.299648 0.131932 0.481306 7.803902 0.089613 0.400547 0.245841 3.151815
 2.547870 0.170887 0.083688 0.037967 1.959291 0.210332 0.245034 0.076701 0.119013 10.649107 1.702745 0.185202 1.898718 0.654683 0.296501 0.098369 2.188158 0.189510 0.249313
-0.079066 0.055941 0.041977 0.053052 0.012937 0.040767 0.071586 0.057337 0.022355 0.062157 0.099081 0.064600 0.022951 0.042302 0.044040 0.061197 0.053287 0.012066 0.034155 0.069146;
+0.07906592 0.05594094 0.04197696 0.05305195 0.01293699 0.04076696 0.07158593 0.05733694 0.02235498 0.06215694 0.0990809 0.06459994 0.02295098 0.04230196 0.04403996 0.06119694 0.05328695 0.01206599 0.03415497 0.06914693;
+[ NOTE 2019-06-04: normalised from original LG freqs, which do not sum to 1.0
+  http://www.atgc-montpellier.fr/download/datasets/models/lg_LG.PAML.txt ]
 
 model MTART=
 0.2
@@ -340,7 +350,8 @@ model MTZOA=
 3.1 16.9 6.4 0.2 36.1 6.1 3.5 12.3 4.5 9.7 27.2 6.6 48.7 58.2 1.3 10.3 3.6
 2.1 13.8 141.6 13.9 76.7 52.3 10.0 4.3 266.5 13.1 5.7 45.0 41.4 590.5 4.2 29.7 29.0 79.8
 321.9 5.1 7.1 3.7 243.8 9.0 16.3 23.7 0.3 1710.6 126.1 11.1 279.6 59.6 17.9 49.5 396.4 13.7 15.6
-0.069 0.021 0.030 0.020 0.010 0.019 0.025 0.072 0.027 0.085 0.157 0.019 0.051 0.082 0.045 0.081 0.056 0.028 0.037 0.066;
+0.06887993 0.02103698 0.03038997 0.02069598 0.00996599 0.01862298 0.02498898 0.07196793 0.02681397 0.08507191 0.15671684 0.01927598 0.05065195 0.08171192 0.04480296 0.08053492 0.05638594 0.02799797 0.03740396 0.06608293;
+[ NOTE 2019-06-04: original mtzoa freqs do not sum to 1.0, modified from PAML package ]
 
 model PMB=
 0.674995699
@@ -362,7 +373,10 @@ model PMB=
 0.350110510 0.618778365 0.422407388 0.362495245 0.445669347 0.720384740 0.261258229 0.378748270 0.724367510 0.516260502 0.794797115 0.433409620 0.768395107 3.295193440 0.499869138 0.496334956 0.383723610
 0.573154753 0.628599063 0.720013799 0.436220437 0.556261630 0.728970584 0.507200030 0.284727562 2.210952064 0.570562395 0.811019594 0.664884513 0.932536060 5.894735673 0.433748126 0.593795813 0.523549536 2.996248013
 2.063050067 0.388680158 0.474418852 0.275658381 0.998911631 0.634408285 0.527640634 0.314700907 0.305792277 8.002789424 2.113077156 0.526184203 1.737356217 0.983844803 0.551333603 0.507506011 1.899650790 0.429570747 0.716795463
-0.076 0.054 0.038 0.045 0.028 0.034 0.053 0.078 0.030 0.060 0.096 0.052 0.022 0.045 0.042 0.068 0.056 0.016 0.036 0.071;
+ 
+ 0.07559244 0.05379462 0.03769623 0.04469553 0.02849715 0.03389661 0.05349465 0.0779922 0.029997 0.05989401 0.09579042 0.0519948 0.02189781 0.0449955 0.0419958 0.06819318 0.05639436 0.01569843 0.0359964 0.07149285;
+ [ NOTE 2019-06-04: normalised from original PMB freqs, which do not sum to 1.0:
+  0.0756 0.0538 0.0377 0.0447 0.0285 0.0339 0.0535 0.0780 0.0300 0.0599 0.0958 0.0520 0.0219 0.0450 0.0420 0.0682 0.0564 0.0157 0.0360 0.0715 ]
 
 model HIVB=
 0.30750700
@@ -428,7 +442,9 @@ model JTTDCMUT=
 0.084329 1.257961 0.027700 0.057466 1.104181 0.172206 0.114381 0.544180 0.128193 0.134510 0.530324 0.089134 0.201334 0.537922 0.069965 0.310927 0.080556
 0.139492 0.235601 0.700693 0.453952 2.114852 0.254745 0.063452 0.052500 5.848400 0.303445 0.241094 0.087904 0.189870 5.484236 0.113850 0.628608 0.201094 0.747889
 2.924161 0.171995 0.164525 0.315261 0.621323 0.179771 0.465271 0.470140 0.121827 9.533943 1.761439 0.124066 3.038533 0.593478 0.211561 0.408532 1.143980 0.239697 0.165473
-0.077 0.051 0.043 0.051 0.020 0.041 0.062 0.075 0.023 0.053 0.091 0.059 0.024 0.040 0.051 0.068 0.059 0.014 0.032 0.066;
+0.07686192 0.05105695 0.04254596 0.05126895 0.02027898 0.04106096 0.06181994 0.07471393 0.02298298 0.05256895 0.09111091 0.05949794 0.02341398 0.04052996 0.05053195 0.06822493 0.05851794 0.01433599 0.03230297 0.06637393;
+[ NOTE 2019-06-04: normalised from original JTTDCMUTT freqs, which do not sum to 1.0
+  https://www.ebi.ac.uk/goldman-srv/dayhoff/jtt-dcmut.dat ]
 
 model FLU=
 0.138658765
@@ -450,8 +466,9 @@ model FLU=
 0.196000000 1.369429408 0.000536000 0.000014900 0.094106680 0.044000000 0.155245492 0.196486447 0.022400000 0.032132150 0.431277663 0.000049800 0.070460039 0.814753094 0.000431021 0.099835753 0.207066206
 0.018289288 0.099855497 0.373101927 0.525398543 0.601692431 0.072205935 0.104092870 0.074814997 6.448954446 0.273934263 0.340058468 0.012416222 0.874272175 5.393924245 0.000182000 0.392552240 0.124898020 0.427755430
 3.532005270 0.103964386 0.010257517 0.297123975 0.054904564 0.406697814 0.285047948 0.337229619 0.098631355 14.394052190 0.890598579 0.073127930 4.904842235 0.592587985 0.058971975 0.088256423 0.654109108 0.256900461 0.167581647
-0.0471 0.0509 0.0742 0.0479 0.0250 0.0333 0.0546 0.0764 0.0200 0.0671 0.0715 0.0568 0.0181 0.0305 0.0507 0.0884 0.0743 0.0185 0.0315 0.0632;
-
+0.04707195 0.05090995 0.07421393 0.04785995 0.02502197 0.03330397 0.05458695 0.07637292 0.01996398 0.06713393 0.07149793 0.05678494 0.01815098 0.03049597 0.05065595 0.08840891 0.07433893 0.01852398 0.03147397 0.06322894;
+[ NOTE 2019-06-04: normalised from FLU freqs in PhyML, which do not sum 1.0 ]
+ 
 model MTMET=
 0.058078177576542
 0.032893910131824 0.141364232590718
@@ -567,7 +584,7 @@ void ModelProtein::init(const char *model_name, string model_params, StateFreqTy
 		double sum = 0.0;
 		for (i = 0; i < num_states; i++)
 			sum += (double) state_freq[i];
-		if (round(sum*1e8) != 1e8) {
+		if (fabs(sum-1.0) > 1e-7) {
 			cout.precision(7);
 			cout << "WARNING: " <<  name_upper << " state frequencies do not sum up to 1: " << sum << endl;
 		}
